/* The name and version of this software distribution. These
 * originates from AM_INIT_AUTOMAKE in the configure.in file. */
#define PACKAGE "configure-generated"
#define VERSION "configure-generated"
 
/* Define if zlib should be used */
#undef WITH_ZLIB
 
/* Define if zlib.h is present */
#undef HAVE_ZLIB_H
 
/* syslog() available? */
#undef HAVE_SYSLOG

/* Use bundled regexps do NOT change */
#define REGEX

/* Default configuration file */
#define CONFIG_FILE "./aide.conf" 

#undef HAVE_BYTE_TYPEDEF
#undef HAVE_USHORT_TYPEDEF
#undef HAVE_ULONG_TYPEDEF
#undef HAVE_U16_TYPEDEF
#undef HAVE_U32_TYPEDEF

/* AIDE compile options */
#undef AIDECOMPILEOPTIONS

#undef HAVE_readdir
#undef HAVE_readdir_r
